lists.openwall.net   lists  /  announce  owl-users  owl-dev  john-users  john-dev  passwdqc-users  yescrypt  popa3d-users  /  oss-security  kernel-hardening  musl  sabotage  tlsify  passwords  /  crypt-dev  xvendor  /  Bugtraq  Full-Disclosure  linux-kernel  linux-netdev  linux-ext4  linux-hardening  linux-cve-announce  PHC 
Open Source and information security mailing list archives
 
Hash Suite: Windows password security audit tool. GUI, reports in PDF.
[<prev] [next>] [<thread-prev] [thread-next>] [day] [month] [year] [list]
Date:	Wed,  2 Jan 2008 15:51:25 -0800
From:	"Brett T. Warden" <brett.warden@...il.com>
To:	linux-kernel@...r.kernel.org, trivial@...nel.org
Cc:	Bill Davidsen <davidsen@....com>,
	Alan Cox <alan@...rguk.ukuu.org.uk>,
	"Brett T. Warden" <brett.warden@...il.com>
Subject: [PATCH] bw-qcam: Rename parameter 'aggressive' to 'force_init'

Changed new parameter name to 'force_init' for clarity, as per feedback.

Signed-off-by: Brett T. Warden <brett.warden@...il.com>
---
 drivers/media/video/bw-qcam.c |    8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/drivers/media/video/bw-qcam.c b/drivers/media/video/bw-qcam.c
index b74a9cb..0322653 100644
--- a/drivers/media/video/bw-qcam.c
+++ b/drivers/media/video/bw-qcam.c
@@ -82,15 +82,15 @@ OTHER DEALINGS IN THE SOFTWARE.
 static unsigned int maxpoll=250;   /* Maximum busy-loop count for qcam I/O */
 static unsigned int yieldlines=4;  /* Yield after this many during capture */
 static int video_nr = -1;
-static unsigned int aggressive;		/* Whether to probe aggressively */
+static unsigned int force_init;		/* Whether to probe aggressively */
 
 module_param(maxpoll, int, 0);
 module_param(yieldlines, int, 0);
 module_param(video_nr, int, 0);
 
 /* Set aggressive=1 to avoid detection by polling status register and
  * immediately attempt to initialize qcam */
-module_param(aggressive, int, 0);
+module_param(force_init, int, 0);
 
 static inline int read_lpstatus(struct qcam_device *q)
 {
@@ -336,7 +336,7 @@ static int qc_detect(struct qcam_device *q)
 	int count = 0;
 	int i;
 
-	if (aggressive)
+	if (force_init)
 		return 1;
 
 	lastreg = reg = read_lpstatus(q) & 0xf0;
@@ -82,15 +82,15 @@ OTHER DEALINGS IN THE SOFTWARE.
 module_param(video_nr, int, 0);
 
-/* Set aggressive=1 to avoid detection by polling status register and
+/* Set force_init=1 to avoid detection by polling status register and
  * immediately attempt to initialize qcam */
-- 
1.5.3.7

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@...r.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Powered by blists - more mailing lists

Powered by Openwall GNU/*/Linux Powered by OpenVZ